@@ -19,19 +19,18 @@ import java.security.NoSuchAlgorithmException;
 import java.util.*;
 import java.util.Map.Entry;
 import org.eclipse.core.runtime.*;
-import org.eclipse.equinox.internal.p2.artifact.processors.md5.MD5Verifier;
 import org.eclipse.equinox.internal.p2.artifact.repository.Messages;
 import org.eclipse.equinox.internal.p2.repository.Activator;
 import org.eclipse.equinox.internal.p2.repository.helpers.ChecksumHelper;
 import org.eclipse.equinox.internal.p2.repository.helpers.ChecksumProducer;
 import org.eclipse.equinox.internal.provisional.p2.artifact.repository.processing.ProcessingStep;
 import org.eclipse.equinox.p2.repository.artifact.IArtifactDescriptor;
+import org.eclipse.equinox.p2.repository.artifact.spi.ProcessingStepDescriptor;
 import org.eclipse.osgi.util.NLS;
 
 public class ChecksumUtilities {
 
 	private static final String ARTIFACT_CHECKSUMS_POINT = "org.eclipse.equinox.p2.artifact.repository.artifactChecksums"; //$NON-NLS-1$
-	private static final String MD5_MESSAGE_DIGEST = "MD5"; //$NON-NLS-1$
 
 	/**
 	 * Instances of checksum verifiers applicable for the artifact descriptor
@@ -57,7 +56,8 @@ public class ChecksumUtilities {
 				String checksumId = checksumVerifierConfiguration.getAttribute("id"); //$NON-NLS-1$
 				if (checksumEntry.getKey().equals(checksumId)) {
 					String checksumAlgorithm = checksumVerifierConfiguration.getAttribute("algorithm"); //$NON-NLS-1$
-					ChecksumVerifier checksumVerifier = new ChecksumVerifier(checksumAlgorithm, checksumId, checksumEntry.getValue());
+					ChecksumVerifier checksumVerifier = new ChecksumVerifier(checksumAlgorithm, checksumId);
+					checksumVerifier.initialize(null, new ProcessingStepDescriptor(null, checksumEntry.getValue(), true), descriptor);
 					if (checksumVerifier.getStatus().isOK())
 						steps.add(checksumVerifier);
 					else
@@ -67,9 +67,6 @@ public class ChecksumUtilities {
 			}
 		}
 
-		Optional<MD5Verifier> legacyMd5Verifier = getLegacyMd5Verifier(checksums.get(ChecksumHelper.MD5));
-		legacyMd5Verifier.ifPresent(verifier -> steps.add(verifier));
-
 		return steps;
 	}
 
@@ -98,12 +95,6 @@ public class ChecksumUtilities {
 			checksum.ifPresent(c -> checksums.put(id, c));
 		}
 
-		boolean doNotSkipMd5 = !checksumsToSkip.contains(ChecksumHelper.MD5);
-		if (doNotSkipMd5) {
-			Optional<String> md5 = calculateChecksum(pathOnDisk, status, ChecksumHelper.MD5, MD5_MESSAGE_DIGEST);
-			md5.ifPresent(c -> checksums.put(ChecksumHelper.MD5, c));
-		}
-
 		return status;
 	}
 
@@ -138,17 +129,6 @@ public class ChecksumUtilities {
 		return properties;
 	}
 
-	private static Optional<MD5Verifier> getLegacyMd5Verifier(String md5) {
-		if (md5 != null) {
-			@SuppressWarnings("resource") //It's used later so shouldn't be closed
-			MD5Verifier checksumVerifier = new MD5Verifier(md5);
-			if (checksumVerifier.getStatus().isOK())
-				return Optional.of(checksumVerifier);
-		}
-
-		return Optional.empty();
-	}
-
 	private static void putLegacyMd5Property(String propertyNamespace, Map<String, String> checksums, HashMap<String, String> result) {
 		String md5 = checksums.get(ChecksumHelper.MD5);
 		if (md5 != null) {
