@@ -1,20 +1,26 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2008 compeople AG and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * Copyright (c) 2007, 2018 compeople AG and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  * 	compeople AG (Stefan Liebig) - initial API and implementation
  *******************************************************************************/
 package org.eclipse.equinox.p2.tests.sar;
 
-import junit.framework.TestCase;
+import static org.junit.Assert.assertEquals;
+
 import org.eclipse.equinox.internal.p2.sar.SarEntry;
+import org.junit.Test;
 
-public class SarEntryTest extends TestCase {
+public class SarEntryTest {
 
+	@Test
 	public void testJavaToDosTimeAndBack() {
 		final long minute = 1000l * 60l;
 		long now = (System.currentTimeMillis() / minute) * minute;
