@@ -14,16 +14,32 @@
 package org.eclipse.equinox.p2.tests.ql;
 
 import java.net.URI;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.Map;
 import org.eclipse.core.runtime.NullProgressMonitor;
-import org.eclipse.equinox.internal.p2.director.*;
+import org.eclipse.equinox.internal.p2.director.PermissiveSlicer;
+import org.eclipse.equinox.internal.p2.director.QueryableArray;
+import org.eclipse.equinox.internal.p2.director.Slicer;
 import org.eclipse.equinox.internal.p2.metadata.InstallableUnit;
 import org.eclipse.equinox.internal.p2.metadata.expression.MatchIteratorFilter;
 import org.eclipse.equinox.internal.p2.metadata.repository.CompositeMetadataRepository;
-import org.eclipse.equinox.p2.metadata.*;
+import org.eclipse.equinox.p2.metadata.IInstallableUnit;
+import org.eclipse.equinox.p2.metadata.IProvidedCapability;
+import org.eclipse.equinox.p2.metadata.IRequirement;
+import org.eclipse.equinox.p2.metadata.MetadataFactory;
+import org.eclipse.equinox.p2.metadata.Version;
+import org.eclipse.equinox.p2.metadata.VersionRange;
 import org.eclipse.equinox.p2.metadata.expression.ExpressionUtil;
 import org.eclipse.equinox.p2.metadata.expression.IExpressionParser;
-import org.eclipse.equinox.p2.query.*;
+import org.eclipse.equinox.p2.publisher.actions.JREAction;
+import org.eclipse.equinox.p2.query.IQuery;
+import org.eclipse.equinox.p2.query.IQueryResult;
+import org.eclipse.equinox.p2.query.IQueryable;
+import org.eclipse.equinox.p2.query.MatchQuery;
+import org.eclipse.equinox.p2.query.QueryUtil;
 import org.eclipse.equinox.p2.repository.metadata.IMetadataRepository;
 import org.eclipse.equinox.p2.repository.metadata.IMetadataRepositoryManager;
 import org.eclipse.equinox.p2.tests.AbstractProvisioningTest;
@@ -239,6 +255,62 @@ public class PerformanceTest extends AbstractProvisioningTest {
 		System.out.println();
 	}
 
+	public void testCapabilityQueryPerformanceEE() throws Exception {
+
+		IMetadataRepository repo = getMDR("/testData/galileoM7");
+
+		Version jreVersion = Version.parseVersion("1.8");
+		Map<String, Object> capAttrs = new HashMap<>();
+		capAttrs.put(JREAction.NAMESPACE_OSGI_EE, "JavaSE");
+		capAttrs.put(JREAction.VERSION_OSGI_EE, jreVersion);
+		IProvidedCapability jreCap = MetadataFactory.createProvidedCapability(JREAction.NAMESPACE_OSGI_EE, capAttrs);
+		IInstallableUnit jre8IU = createIU("a.jre.javase", jreVersion, new IProvidedCapability[] {jreCap});
+		repo.addInstallableUnits(Collections.singletonList(jre8IU));
+
+		jreVersion = Version.parseVersion("1.9");
+		capAttrs = new HashMap<>();
+		capAttrs.put(JREAction.NAMESPACE_OSGI_EE, "JavaSE");
+		capAttrs.put(JREAction.VERSION_OSGI_EE, jreVersion);
+		jreCap = MetadataFactory.createProvidedCapability(JREAction.NAMESPACE_OSGI_EE, capAttrs);
+		IInstallableUnit jre9IU = createIU("b.jre.anotherjavase", jreVersion, new IProvidedCapability[] {jreCap});
+		repo.addInstallableUnits(Collections.singletonList(jre9IU));
+
+		IRequirement capability = MetadataFactory.createRequirement(JREAction.NAMESPACE_OSGI_EE, "(&(osgi.ee=JavaSE)(version=1.8))", null, 0, 0, false);
+		IQuery<IInstallableUnit> capabilityQuery = QueryUtil.createMatchQuery(capability.getMatches());
+		IQueryResult<IInstallableUnit> result;
+		long tradQueryMS = 0;
+
+		for (int i = 0; i < 5; ++i) {
+			long start = System.currentTimeMillis();
+			for (int idx = 0; idx < 80; ++idx) {
+				result = repo.query(capabilityQuery, new NullProgressMonitor());
+				assertEquals(1, queryResultSize(result));
+				assertEquals(jre8IU, result.toUnmodifiableSet().iterator().next());
+			}
+			tradQueryMS += (System.currentTimeMillis() - start);
+		}
+		System.out.println("CapabilityQuery took: " + tradQueryMS + " milliseconds");
+		System.out.println();
+	}
+
+	public void testCapabilityQueryPerformanceOsgiService() throws Exception {
+
+		IMetadataRepository repo = getMDR("/testData/2018-12");
+
+		IRequirement capability = MetadataFactory.createRequirement("osgi.service", "(objectClass=org.osgi.service.event.EventAdmin)", null, 0, 0, false);
+		IQuery<IInstallableUnit> capabilityQuery = QueryUtil.createMatchQuery(capability.getMatches());
+		IQueryResult<IInstallableUnit> result;
+
+		long start = System.currentTimeMillis();
+		for (int i = 0; i < 1000; ++i) {
+			result = repo.query(capabilityQuery, new NullProgressMonitor());
+			assertEquals(1, queryResultSize(result));
+			assertEquals("org.eclipse.equinox.event", result.iterator().next().getId());
+		}
+		System.out.println("1000 * CapabilityQuery for osgi.service took: " + (System.currentTimeMillis() - start) + " milliseconds");
+		System.out.println();
+	}
+
 	public void testIUPropertyQueryPerformance() throws Exception {
 
 		IMetadataRepository repo = getMDR("/testData/galileoM7");
@@ -364,7 +436,7 @@ public class PerformanceTest extends AbstractProvisioningTest {
 	private IMetadataRepository getMDR(String uri) throws Exception {
 		URI metadataRepo = getTestData("1.1", uri).toURI();
 
-		IMetadataRepositoryManager metadataManager = (IMetadataRepositoryManager) getAgent().getService(IMetadataRepositoryManager.SERVICE_NAME);
+		IMetadataRepositoryManager metadataManager = getAgent().getService(IMetadataRepositoryManager.class);
 		assertNotNull(metadataManager);
 
 		return metadataManager.loadRepository(metadataRepo, new NullProgressMonitor());
