@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2013 IBM Corporation and others.
+ * Copyright (c) 2008, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -16,7 +16,7 @@ package org.eclipse.equinox.p2.tests.simpleconfigurator;
 
 import org.eclipse.equinox.internal.simpleconfigurator.Activator;
 
-public class SimpleConfiguratorUtilsExtendedTest extends SimpleConfiguratorTest {
+public class SimpleConfiguratorUtilsExtendedTest extends SimpleConfiguratorUtilsTest {
 
 	@Override
 	public void setUp() throws Exception {
