@@ -1,9 +1,12 @@
 /*******************************************************************************
- * Copyright (c) 2009, Cloudsmith Inc and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * Copyright (c) 2009, 2018 Cloudsmith Inc and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Cloudsmith Inc. - initial API and implementation
@@ -24,6 +27,7 @@ public class TimeOut extends HttpServlet {
 	private static final long serialVersionUID = 1L;
 	private static long MINUTES_MS = 1000 * 60; // minutes in ms
 
+	@Override
 	protected void doGet(HttpServletRequest request, HttpServletResponse response) {
 		doDelay();
 	}
@@ -37,6 +41,7 @@ public class TimeOut extends HttpServlet {
 		}
 	}
 
+	@Override
 	protected void doHead(HttpServletRequest request, HttpServletResponse response) {
 		doDelay();
 	}
